@@ -17,7 +17,7 @@ use App::Memcached::CLI::Help;
 use App::Memcached::CLI::Item;
 use App::Memcached::CLI::Util ':all';
 
-use version; our $VERSION = 'v0.7.0';
+use version; our $VERSION = 'v0.7.1';
 
 my $PROGRAM = basename $0;
 
@@ -39,6 +39,8 @@ my %COMMAND2ALIASES = (
     append     => [],
     prepend    => [],
     cas        => [],
+    incr       => [],
+    decr       => [],
     touch      => [],
     delete     => [],
     flush_all  => [qw(flush)],
@@ -301,6 +303,31 @@ sub cas {
     return 1;
 }
 
+sub incr { return &_incr_decr(shift, 'incr', @_); }
+sub decr { return &_incr_decr(shift, 'decr', @_); }
+
+sub _incr_decr {
+    my $self   = shift;
+    my $cmd    = shift;
+    my $key    = shift;
+    my $number = shift;
+    unless ($key and defined $number) {
+        print "No KEY or VALUE specified.\n";
+        return;
+    }
+    unless ($number =~ m/^\d+$/) {
+        print "Give numeric number for $cmd VALUE.\n";
+        return;
+    }
+    my $new_value = $self->{ds}->$cmd($key, $number);
+    unless (defined $new_value) {
+        print "FAILED - $cmd\n";
+        return;
+    }
+    print "OK. New VALUE is $new_value\n";
+    return 1;
+}
+
 sub touch {
     my $self   = shift;
     my $key    = shift;
@@ -309,6 +336,10 @@ sub touch {
         print "No KEY or EXPIRE specified.\n";
         return;
     }
+    unless ($expire =~ m/^\d+$/) {
+        print "Give numeric number for EXPIRE.\n";
+        return;
+    }
     unless ($self->{ds}->touch($key, $expire)) {
         print "Failed to touch. KEY $key maybe missing\n";
         return;
